#
# db2_secured::controls::authentication_type_for_incoming_connections_at_the_server_srvcon_auth
#
# @summary The `srvcon_auth` parameter defines where and how user authentication is done for incoming connections at the server.
# If no value is used, DB2 uses the database manager configuration parameter authentication.
# 
# Rationale:
# 
# Incoming connections to the DB2 server must follow an authentication protocol. The `srvcon_auth` server configuration parameter defines how and where user authentication is done.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::authentication_type_for_incoming_connections_at_the_server_srvcon_auth: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::authentication_type_for_incoming_connections_at_the_server_srvcon_auth::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `authentication_type_for_incoming_connections_at_the_server_srvcon_auth` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.2.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::authentication_type_for_incoming_connections_at_the_server_srvcon_auth (
  Variant[String[1], Integer] $preferred_value = db2_secured::lookup_setting('preferred_value', 'SERVER'),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "authentication_type_for_incoming_connections_at_the_server_srvcon_auth on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]srvcon_auth/2":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
