#
# db2_secured::controls::restrict_access_to_sysibm_syswrapoptions
#
# @summary he `SYSIBM.
# SYSWRAPOPTIONS` table contains wrapper-specific options. It is recommended that the `PUBLIC`  role be restricted from accessing this table.
# 
# Rationale:
# 
# Any databases created without the `RESTRICT` option automatically `GRANT`  the `SELECT`  privilege to `PUBLIC`  for SYSIBM tables. Therefore, it is strongly recommended to explicitly `REVOKE`  the `SELECT`  privilege on tSYSWRAPOPTIONS` table from `PUBLIC`  to reduce risk to the organization's data.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::restrict_access_to_sysibm_syswrapoptions: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::restrict_access_to_sysibm_syswrapoptions::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `restrict_access_to_sysibm_syswrapoptions` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.3.45
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_sysibm_syswrapoptions {
  db2_secured_setup { "restrict_access_to_sysibm_syswrapoptions on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSIBM.SYSWRAPOPTIONS": }
}
