#
# db2_secured::controls::review_role_grantees_with_with_admin_option
#
# @summary Using the `WITH ADMIN OPTION` clause of the `GRANT` (Role) SQL statement, the security administrator can delegate the management and control of membership in a role to someone else.
# Rationale:
# 
# The `WITH ADMIN OPTION` clause gives another user the authority to grant membership in the role to other users, to revoke membership in the role from other members of the role, and to comment on a role, but not to drop the role.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::review_role_grantees_with_with_admin_option: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::review_role_grantees_with_with_admin_option::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `review_role_grantees_with_with_admin_option` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::review_role_grantees_with_with_admin_option {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "review_role_grantees_with_with_admin_option on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
