#
# db2_secured::controls::set_failed_archive_retry_delay
#
# @summary The `archretrydelay` parameter specifies the number of seconds the DB2 service will wait before it reattempts to archive log files after a failure.
# It is recommended that this parameter be set anywhere in the range of 10-30. You do not want the delay to be so short that the database ends up in a denial of service scenario, but you don't want the delay to be too long if an outside attack happens at the same time.
# 
# Rationale:
# 
# Ensure that the value is non-zero, otherwise archive logging will not retry after the first failure. A denial of service attack can render the database without an archive log if this setting is not set. An archive log will ensure that all transactions can safely be restored or logged for auditing.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_failed_archive_retry_delay: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_failed_archive_retry_delay::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_failed_archive_retry_delay` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.14
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_failed_archive_retry_delay (
  Integer[10,30] $preferred_value = db2_secured::lookup_setting('preferred_value', 20),
) {
  db2_secured_setup { "set_failed_archive_retry_delay on ${title}":
    ensure => 'present',
  }

  # resource_value { "Db2_database[${title}]archretrydelay":
  #   allow_create   => true,
  #   allow_redefine => true,
  #   value          => $preferred_value,
  # }
}
