#
# db2_secured::controls::set_maximum_connection_limits_max_connections_and_max_coordagents
#
# @summary TODO: Write documentation
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_maximum_connection_limits_max_connections_and_max_coordagents: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_maximum_connection_limits_max_connections_and_max_coordagents::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_maximum_connection_limits_max_connections_and_max_coordagents` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.8
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_maximum_connection_limits_max_connections_and_max_coordagents (
  Integer $preferred_value = db2_secured::lookup_setting('preferred_value', 200),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $lower_value = $preferred_value -1

  db2_secured_setup { "set_maximum_connection_limits_max_connections_and_max_coordagents on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]max_coordagents":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }

  resource_value { "Db2_instance[${instance}]max_connections":
    allow_create   => true,
    allow_redefine => true,
    value          => -1,
  }
}
