#
# db2_secured::controls::use_ip_address_rather_than_hostname
#
# @summary Use an IP address rather than a hostname to connect to the host of the DB2 instance.
# Rationale:
# 
# Using a hostname to connect to a DB2 instance can display useful information about the host to an attacker. For example, hostnames for DB2 instances often contain the DB2 version number, host type, or operating system type## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::use_ip_address_rather_than_hostname: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::use_ip_address_rather_than_hostname::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_ip_address_rather_than_hostname` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 1.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::use_ip_address_rather_than_hostname {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "use_ip_address_rather_than_hostname on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
